/*
 * Copyright (C) 2022 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#pragma once

#include <stdio.h>

// Mock definitions for the Trusty logging macros. These are not
// meant to be run, just compiled successfully.
#define TLOGD(fmt, ...) printf(fmt, ##__VA_ARGS__)
#define TLOGI(fmt, ...) printf(fmt, ##__VA_ARGS__)
#define TLOGW(fmt, ...) printf(fmt, ##__VA_ARGS__)
#define TLOGE(fmt, ...) printf(fmt, ##__VA_ARGS__)
#define TLOGC(fmt, ...) printf(fmt, ##__VA_ARGS__)

#define _tlog(fmt, ...) printf(fmt, ##__VA_ARGS__)
#define _vtlog(fmt, args) vprintf(fmt, args)
